---
feature_story: FS_51_67_38_37
feature_title: impossible arg combinations
feature_status: TEST
---

TODO: There is no a single test tagged by this feature - add existing test or create new.

It is possible to input impossible combination of args which will all get consumed, for example:

```sh
relay_demo goto service dev upstream apac xx
```

In this case, there is no `xx` service with all other args in place (see TD_63_37_05_36 demo data).<br/>
However, it is consumed as service name because such service exists in the data set.<br/>
But there is no object selected and any command expecting 1...N objects will fail.

It happens because consumption of args is based on initial "enum query" with full universe of values per arg types.

Note that it is impossible to get there by auto-completing - to get this combination,<br/>
some args (e.g. `xx` in this case) should be specified by user typing them by hands instead.

This is a known minor issue (since auto-completion does not get you there).<br/>
Some may even consider it as a feature as user might want to lock `xx` value and<br/>
modify the rest of args via subsequent completion.
